local AL = AceLibrary("AceLocale-2.2"):new("AtlasLoot");
local GREY = "|cff999999";
local RED = "|cffff0000";
local WHITE = "|cffFFFFFF";
local GREEN = "|cff1eff00";
local PURPLE = "|cff9F3FFF";
local BLUE = "|cff0070dd";
local ORANGE = "|cffFF8400";
local DEFAULT = "|cffFFd200";
local ParseTooltip_Enabled = false;

--------------------------------------------------------------------------------
-- Item OnEnter
-- Called when a loot item is moused over
--------------------------------------------------------------------------------
function AtlasLootItem_OnEnter()
    AtlasLootTooltip:ClearLines();
    for i=1, 30, 1 do
        if (getglobal("AtlasLootTooltipTextRight"..i) ~= nil) then
            getglobal("AtlasLootTooltipTextRight"..i):SetText("");
        end
    end
    if (this.itemID ~= 0) then
        local yOffset;
        local color = strsub(getglobal("AtlasLootItem_"..this:GetID().."_Name"):GetText(), 3, 10);
        local name = strsub(getglobal("AtlasLootItem_"..this:GetID().."_Name"):GetText(), 11);
        if(this.itemID ~= 0 and this.itemID ~= "" and this.itemID ~= nil and AtlasLootDKPValues and AtlasLootClassPriority) then
            Identifier = "Item"..this.itemID;
            DKP = AtlasLootDKPValues[Identifier];
            priority = AtlasLootClassPriority[Identifier];
        else
            DKP = nil;
            priority = nil;
        end
        --Lootlink tooltips
        if( AtlasLootOptions.LootlinkTT ) then
            --If we have seen the item, use the game tooltip to minimise same name item problems
            if(GetItemInfo(this.itemID) ~= nil) then
                AtlasLootTooltip:SetOwner(this, "ANCHOR_RIGHT", -(this:GetWidth() / 2), 24);
                AtlasLootTooltip:SetHyperlink("item:"..this.itemID..":0:0:0");
                if ( AtlasLootOptions.ItemIDs ) then
                    AtlasLootTooltip:AddLine(BLUE..AL["ItemID:"].." "..this.itemID, nil, nil, nil, 1);
                end
                if( this.droprate ~= nil) then
                    AtlasLootTooltip:AddLine(AL["Drop Rate: "]..this.droprate, 1, 1, 0);
                end
                if( DKP ~= nil and DKP ~= "" ) then
                    AtlasLootTooltip:AddLine(RED..DKP.." "..AL["DKP"], 1, 1, 0, 1);
                end
                if( priority ~= nil and priority ~= "" ) then
                    AtlasLootTooltip:AddLine(GREEN..AL["Priority:"].." "..priority, 1, 1, 0, 1);
                end
                AtlasLootTooltip:Show();
                if(AtlasLootOptions.EquipCompare and not EquipCompare_RegisterTooltip) then
                    AtlasLootItem_ShowCompareItem(); --- CALL MISSING METHOD TO SHOW 2 TOOLTIPS (Item Compare)
                end
                if (LootLink_AddItem) then
                    LootLink_AddItem(name, this.itemID..":0:0:0", color);
                end
            else
                AtlasLootTooltip:SetOwner(this, "ANCHOR_RIGHT", -(this:GetWidth() / 2), 24);
                if (LootLink_Database and LootLink_Database[this.itemID]) then
                   LootLink_SetTooltip(AtlasLootTooltip, LootLink_Database[this.itemID][1], 1);
                else
                   LootLink_SetTooltip(AtlasLootTooltip,strsub(getglobal("AtlasLootItem_"..this:GetID().."_Name"):GetText(), 11), 1);
                end
                if ( AtlasLootOptions.ItemIDs ) then
                    AtlasLootTooltip:AddLine(BLUE..AL["ItemID:"].." "..this.itemID, nil, nil, nil, 1);
                end
                if( this.droprate ~= nil) then
                    AtlasLootTooltip:AddLine(AL["Drop Rate: "]..this.droprate, 1, 1, 0, 1);
                end
                if( DKP ~= nil and DKP ~= "" ) then
                    AtlasLootTooltip:AddLine(RED..DKP.." "..AL["DKP"], 1, 1, 0);
                end
                if( priority ~= nil and priority ~= "" ) then
                    AtlasLootTooltip:AddLine(GREEN..AL["Priority:"].." "..priority, 1, 1, 0);
                end
                AtlasLootTooltip:AddLine(" ");
                AtlasLootTooltip:AddLine(AL["You can right-click to attempt to query the server.  You may be disconnected."], nil, nil, nil, 1);
                if(AtlasLootTooltipTextLeft1==" " and AtlasLootTooltipDB[this.itemID]) then
                    AtlasLoot_GenerateTooltip(AtlasLootTooltipDB[this.itemID]);
                else
                    AtlasLootTooltip:Show();
                end
            end
        --Item Sync tooltips
        elseif( AtlasLootOptions.ItemSyncTT ) then
            ItemSync:ButtonEnter();
            if ( AtlasLootOptions.ItemIDs ) then
                GameTooltip:AddLine(BLUE..AL["ItemID:"].." "..this.itemID, nil, nil, nil, 1);
            end
            if( this.droprate ~= nil) then
                GameTooltip:AddLine(AL["Drop Rate: "]..this.droprate, 1, 1, 0);
            end
            if( DKP ~= nil and DKP ~= "" ) then
                GameTooltip:AddLine(RED..DKP.." "..AL["DKP"], 1, 1, 0);
            end 
            if( priority ~= nil and priority ~= "" ) then
                GameTooltip:AddLine(GREEN..AL["Priority:"].." "..priority, 1, 1, 0);
            end
            GameTooltip:Show();
            if(AtlasLootOptions.EquipCompare and not EquipCompare_RegisterTooltip) then
                GameTooltip_ShowCompareItem(); --- CALL MISSING METHOD TO SHOW 2 TOOLTIPS (Item Compare)
            end
        --Default game tooltips
        else
            if(this.itemID ~= nil) then
                if(GetItemInfo(this.itemID) ~= nil) then
                    AtlasLootTooltip:SetOwner(this, "ANCHOR_RIGHT", -(this:GetWidth() / 2), 24);
                    AtlasLootTooltip:SetHyperlink("item:"..this.itemID..":0:0:0");
                    if ( AtlasLootOptions.ItemIDs ) then
                        AtlasLootTooltip:AddLine(BLUE..AL["ItemID:"].." "..this.itemID, nil, nil, nil, 1);
                    end
                    if( this.droprate ~= nil) then
                        AtlasLootTooltip:AddLine(AL["Drop Rate: "]..this.droprate, 1, 1, 0);
                    end
                    if( DKP ~= nil and DKP ~= "" ) then
                        AtlasLootTooltip:AddLine(RED..DKP.." "..AL["DKP"], 1, 1, 0);
                    end
                    if( priority ~= nil and priority ~= "" ) then
                        AtlasLootTooltip:AddLine(GREEN..AL["Priority:"].." "..priority, 1, 1, 0);
                    end
                    AtlasLootTooltip:Show();
                    if(AtlasLootOptions.EquipCompare and not EquipCompare_RegisterTooltip) then
                        AtlasLootItem_ShowCompareItem(); --- CALL MISSING METHOD TO SHOW 2 TOOLTIPS (Item Compare)
                    end
                else
                    AtlasLootTooltip:SetOwner(this, "ANCHOR_RIGHT", -(this:GetWidth() / 2), 24);
                    AtlasLootTooltip:ClearLines();
                    AtlasLootTooltip:AddLine(RED..AL["Unsafe Item"], nil, nil, nil, 1);
                    AtlasLootTooltip:AddLine(BLUE..AL["ItemID:"].." "..this.itemID, nil, nil, nil, 1);
                    AtlasLootTooltip:AddLine(AL["This item is unsafe.  To view this item without the risk of disconnection, you need to have first seen it in the game world. This is a restriction enforced by Blizzard since Patch 1.10."], nil, nil, nil, 1);
                    AtlasLootTooltip:AddLine(" ");
                    AtlasLootTooltip:AddLine(AL["You can right-click to attempt to query the server.  You may be disconnected."], nil, nil, nil, 1);
                    AtlasLootTooltip:Show();
                end
            end
        end
    end
end

--------------------------------------------------------------------------------
-- Item OnLeave
-- Called when the mouse cursor leaves a loot item
--------------------------------------------------------------------------------
function AtlasLootItem_OnLeave()
    --Hide the necessary tooltips
    if( AtlasLootOptions.LootlinkTT ) then
        AtlasLootTooltip:Hide();
    elseif( AtlasLootOptions.ItemSyncTT ) then
        if(GameTooltip:IsVisible()) then
            GameTooltip:Hide();
        end
    else
        if(this.itemID ~= nil) then
		    AtlasLootTooltip:Hide();
            GameTooltip:Hide();
	    end
    end
    if ( ShoppingTooltip2:IsVisible() or ShoppingTooltip1.IsVisible) then
       ShoppingTooltip2:Hide();
       ShoppingTooltip1:Hide();
    end
end

--------------------------------------------------------------------------------
-- Item OnClick
-- Called when a loot item is clicked on
--------------------------------------------------------------------------------
function AtlasLootItem_OnClick(arg1)
	local color = strsub(getglobal("AtlasLootItem_"..this:GetID().."_Name"):GetText(), 1, 10);
	local id = this:GetID();
	local name = strsub(getglobal("AtlasLootItem_"..this:GetID().."_Name"):GetText(), 11);
	local iteminfo = GetItemInfo(this.itemID);
    local itemName, itemLink, itemQuality, itemLevel, itemMinLevel, itemType, itemSubType, itemCount, itemEquipLoc, itemTexture = GetItemInfo(this.itemID);
    --If shift-clicked, link in the chat window
    if(arg1=="RightButton" and not iteminfo and this.itemID ~= 0) then
        AtlasLootTooltip:SetHyperlink("item:"..this.itemID..":0:0:0:0:0:0:0");
        DEFAULT_CHAT_FRAME:AddMessage(AL["Server queried for "]..color.."["..name.."]".."|r"..AL[".  Right click on any other item to refresh the loot page."]);
        AtlasLootItemsFrame:Hide();
        AtlasLoot_ShowItemsFrame(AtlasLootItemsFrame.refresh[1], AtlasLootItemsFrame.refresh[2], AtlasLootItemsFrame.refresh[3], AtlasLootItemsFrame.refresh[4]);
    elseif(arg1=="RightButton" and iteminfo) then
        AtlasLootItemsFrame:Hide();
        AtlasLoot_ShowItemsFrame(AtlasLootItemsFrame.refresh[1], AtlasLootItemsFrame.refresh[2], AtlasLootItemsFrame.refresh[3], AtlasLootItemsFrame.refresh[4]);
        DEFAULT_CHAT_FRAME:AddMessage(itemLink..AL[" is safe."]);
	elseif(IsShiftKeyDown() and iteminfo and (AtlasLootOptions.SafeLinks or AtlasLootOptions.AllLinks)) then
    	ChatEdit_InsertLink(itemLink);
	elseif(IsShiftKeyDown() and AtlasLootOptions.AllLinks) then
		ChatEdit_InsertLink(color.."|Hitem:"..this.itemID..":0:0:0:0:0:0:0|h["..name.."]|h|r");
    elseif(ChatFrameEditBox:IsVisible()) then
		ChatFrameEditBox:Insert(name);  -- <-- this line just inserts plain text, does not need any adjustment
    --If control-clicked, use the dressing room
    elseif(IsControlKeyDown() and iteminfo) then
        DressUpItemLink(itemLink);
	end
end

-------
-- Missing GameToolTip method
-- Enables item comparing. I've ripped this method directly from GameTooltip.lua and modified to work with AtlasLootTooltip /siena
-------
function AtlasLootItem_ShowCompareItem()
   local item,link= AtlasLootTooltip:GetItem();
    if ( not link ) then
      return;
   end
   
   local item1 = nil;
   local item2 = nil;
   local side = "left";
   if ( ShoppingTooltip1:SetHyperlinkCompareItem(link, 1) ) then
      item1 = true;
   end
   if ( ShoppingTooltip2:SetHyperlinkCompareItem(link, 2) ) then
      item2 = true;
   end
   local rightDist = GetScreenWidth() - AtlasLootTooltip:GetRight();
   if (rightDist < AtlasLootTooltip:GetLeft()) then
      side = "left";
   else
      side = "right";
   end
   if ( AtlasLootTooltip:GetAnchorType() ) then
      local totalWidth = 0;
      if ( item1  ) then
         totalWidth = totalWidth + ShoppingTooltip1:GetWidth();
      end
      if ( item2  ) then
         totalWidth = totalWidth + ShoppingTooltip2:GetWidth();
      end

      if ( (side == "left") and (totalWidth > AtlasLootTooltip:GetLeft()) ) then
         AtlasLootTooltip:SetAnchorType(AtlasLootTooltip:GetAnchorType(), (totalWidth - AtlasLootTooltip:GetLeft()), 0);
      elseif ( (side == "right") and (AtlasLootTooltip:GetRight() + totalWidth) >  GetScreenWidth() ) then
         AtlasLootTooltip:SetAnchorType(AtlasLootTooltip:GetAnchorType(), -((AtlasLootTooltip:GetRight() + totalWidth) - GetScreenWidth()), 0);
      end
   end

   -- anchor the compare tooltips
   if ( item1 ) then
      ShoppingTooltip1:SetOwner(AtlasLootTooltip, "ANCHOR_NONE");
      ShoppingTooltip1:ClearAllPoints();
      if ( side and side == "left" ) then
         ShoppingTooltip1:SetPoint("TOPRIGHT", "AtlasLootTooltip", "TOPLEFT", 0, -10);
      else
         ShoppingTooltip1:SetPoint("TOPLEFT", "AtlasLootTooltip", "TOPRIGHT", 0, -10);
      end
      ShoppingTooltip1:SetHyperlinkCompareItem(link, 1);
      ShoppingTooltip1:Show();

      if ( item2 ) then
         ShoppingTooltip2:SetOwner(ShoppingTooltip1, "ANCHOR_NONE");
         ShoppingTooltip2:ClearAllPoints();
         if ( side and side == "left" ) then
            ShoppingTooltip2:SetPoint("TOPRIGHT", "ShoppingTooltip1", "TOPLEFT", 0, 0);
         else
            ShoppingTooltip2:SetPoint("TOPLEFT", "ShoppingTooltip1", "TOPRIGHT", 0, 0);
         end
         ShoppingTooltip2:SetHyperlinkCompareItem(link, 2);
         ShoppingTooltip2:Show();
      end
   end   
end

function AtlasLoot_ParseTooltip(IDno)
    if(AtlasLootSavedTooltips[IDno]) then 
        return; 
    else
        AtlasLootSavedTooltips[IDno]={};
    end
    AtlasLootTooltip:ClearLines();
    AtlasLootTooltip:SetHyperlink("item:"..IDno..":0:0:0:0:0:0:0");
    line=0;
    for index = 1, 30, 1 do
        line=line+1;
        r,g,b,_ = getglobal("AtlasLootTooltipTextLeft"..index):GetTextColor();
        if(line==1) then
            local itemName, itemLink, quality, itemLevel, itemMinLevel, itemType, itemSubType, itemCount, itemEquipLoc, itemTexture = GetItemInfo(IDno);
            _, _, _, colour = GetItemQualityColor(quality);
        else
            colour = AtlasLoot_CheckColour(r, g, b);
        end
        text=getglobal("AtlasLootTooltipTextLeft"..index):GetText();
        if(text==nil or text=="\n" or text==" \n") then
            return;
        else
            AtlasLootSavedTooltips[IDno][line]=colour..text;
        end
        line=line+1;
        r,g,b,_ = getglobal("AtlasLootTooltipTextRight"..index):GetTextColor();
        colour = AtlasLoot_CheckColour(r, g, b);
        text=getglobal("AtlasLootTooltipTextRight"..index):GetText();
        if(text==nil) then
            AtlasLootSavedTooltips[IDno][line] = "";
        else
            AtlasLootSavedTooltips[IDno][line]=colour..text;
        end
    end
end

function AtlasLoot_CheckColour(r, g, b)
    if( r==0.5019596815109253 and g==0.5019596815109253 and b==0.5019596815109253 ) then
        return GREY;
    elseif( r==0.9999978030100465 and g==0.8235275745391846 and b==0 ) then
        return DEFAULT;
    elseif( r==0.9999978030100465 and g==0.1254899203777313 and b==0.1254899203777313 ) then
        return RED;
    elseif( r==0.9999978030100465 and g==0.9999977946281433 and b==0.9999977946281433) then
        return WHITE;
    elseif( r==0.6392142819240689 and g==0.2078426778316498 and b==0.933331310749054 ) then
        return PURPLE;
    elseif( r==0.63921428192407 and g==0.20784267783165 and b==0.93333131074905 ) then
        return PURPLE;
    elseif( r==0 and g==0.9999977946281433 and b==0) then
        return GREEN;
    elseif( r==0.1176468003541231 and g==0.9999977946281433 and b==0) then
        return GREEN;
    elseif( r==0 and g==0.4392147064208984 and b==0.8666647672653198 ) then
        return BLUE;
    elseif( r==0.9999978030100465 and g==0.5019596815109253 and b==0) then
        return ORANGE;
    else
        return WHITE;
    end
end

   
